# Zen Sight

## Overview

Provides a Python API for interactive simplicial complex visualizations. Zen Sight is still a work in progress, the API is not finalized.

## Example Usage
- Clone the repo
- Sync dependencies
- Create an editable pip install

```bash
git clone https://github.com/Jamiller137/zen-sight.git
cd zen-sight
pip install -e .
```

See `example.py`

Running the example will cause a Zen Sight window to open in your browser.

## Dependencies

- react-force-graph-2d
- react-force-graph-3d
- Three.js
- **Flask** >= 3.1.0: Python web framework for serving the visualization
- NOTE: Not update
